package de.intevation.flys.artifacts.states;

import java.util.List;

import org.apache.log4j.Logger;

import de.intevation.artifacts.CallMeta;

import de.intevation.artifactdatabase.state.Facet;

import de.intevation.flys.artifacts.AnnotationArtifact;
import de.intevation.flys.artifacts.FLYSArtifact;

import de.intevation.flys.artifacts.model.AnnotationFacet;
import de.intevation.flys.artifacts.model.FacetTypes;

import de.intevation.flys.artifacts.resources.Resources;


/**
 * The only state for an AnnotationArtifact (River is known).
 */
public class AnnotationRiverState
extends      DefaultState
implements   FacetTypes
{
    /** Developer-centric description of facet. */
    public static final String I18N_DESCRIPTION = "facet.longitudinal_section.annotations";

    /** The logger that is used in this state. */
    private static final Logger logger = Logger.getLogger(AnnotationRiverState.class);


    /**
     * Add an AnnotationFacet to list of Facets.
     *
     * @param artifact Ignored.
     * @param hash Ignored.
     * @param context Ignored.
     * @param meta CallMeta to be used for internationalization.
     * @param facets List to add AnnotationFacet to.
     *
     * @return null.
     */
    @Override
    public Object computeInit(
        FLYSArtifact artifact,
        String       hash,
        Object       context,
        CallMeta     meta,
        List<Facet>  facets
    ) {
        logger.debug("AnnotationRiverState.computeInit()");

        AnnotationArtifact annotationArtifact = (AnnotationArtifact) artifact;

        String facetName = annotationArtifact.getFilterName();
        if (facetName == null) {
            facetName = Resources.getMsg(meta, I18N_DESCRIPTION, I18N_DESCRIPTION);
        }

        AnnotationFacet facet = new AnnotationFacet(
            0,
            LONGITUDINAL_ANNOTATION,
            facetName);
        facets.add(facet);

        return null;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
